@@ -3,10 +3,15 @@
 #'
 #' @description Predicts benefit score based on a fitted subgroup identification model
 #'
-#' @param object fitted object returned by \code{validate.subgrp()} function
+#' @param object fitted object returned by \code{validate.subgrp()} function.
+#'
+#' For \code{predict.wksvm()}, this should be a fitted \code{wksvm} object from the \code{weighted.ksvm()} function
 #' @param newx new design matrix for which predictions will be made
-#' @param type type of prediction. \code{"benefit.score"} results in predicted benefit scores and
-#' \code{"trt.group"} results in prediction of recommended treatment group
+#' @param type type of prediction. \code{type = "benefit.score"} results in predicted benefit scores and
+#' \code{type = "trt.group"} results in prediction of recommended treatment group.
+#'
+#' For \code{predict.wksvm()}, \code{type = 'class'} yields predicted
+#' class and \code{type = 'linear.predictor'} yields estimated function (the sign of which is the estimated class)
 #' @param cutpoint numeric value for patients with benefit scores above which
 #' (or below which if \code{larger.outcome.better = FALSE})
 #' will be recommended to be in the treatment group
@@ -70,7 +75,13 @@ predict.subgroup_fitted <- function(object,
 
     # simply call prediction function
     # defined by the loss function used
-    retval <- drop(object$predict(newx))
+    if (grepl("owl_", object$loss) & object$n.trts > 2 & type == "trt.group")
+    {
+        retval <- drop(object$predict(newx, type = "class"))
+    } else
+    {
+        retval <- drop(object$predict(newx))
+    }
 
     # need to make predicted (ie recommended)
     # treatment behavior different if larger
@@ -79,23 +90,29 @@ predict.subgroup_fitted <- function(object,
     {
         if (object$n.trts > 2)
         {
-            # meaning of larger vs smaller benefit score
-            # is different depending on whether larger means
-            # better or not for the outcome
-            if (object$larger.outcome.better)
+            if (grepl("owl_", object$loss))
             {
-                best.comp.idx   <- apply(retval, 1, which.max)
-                recommended.trt <- 1 * (retval > cutpoint)
-                rec.ref         <- rowSums(recommended.trt) == 0
-
-                retval <- ifelse(rec.ref, object$reference.trt, object$comparison.trts[best.comp.idx])
+                # nothing to be done
             } else
             {
-                best.comp.idx   <- apply(retval, 1, which.min)
-                recommended.trt <- 1 * (retval < cutpoint)
-                rec.ref         <- rowSums(recommended.trt) == 0
+                # meaning of larger vs smaller benefit score
+                # is different depending on whether larger means
+                # better or not for the outcome
+                if (object$larger.outcome.better)
+                {
+                    best.comp.idx   <- apply(retval, 1, which.max)
+                    recommended.trt <- 1 * (retval > cutpoint)
+                    rec.ref         <- rowSums(recommended.trt) == 0
 
-                retval <- ifelse(rec.ref, object$reference.trt, object$comparison.trts[best.comp.idx])
+                    retval <- ifelse(rec.ref, object$reference.trt, object$comparison.trts[best.comp.idx])
+                } else
+                {
+                    best.comp.idx   <- apply(retval, 1, which.min)
+                    recommended.trt <- 1 * (retval < cutpoint)
+                    rec.ref         <- rowSums(recommended.trt) == 0
+
+                    retval <- ifelse(rec.ref, object$reference.trt, object$comparison.trts[best.comp.idx])
+                }
             }
 
         } else
